/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * 
 */

package demoApp;

import java.io.*;
import java.util.*;
import com.lutris.util.*;
import com.lutris.logging.Logger;
import com.lutris.logging.LogChannel;
import com.lutris.appserver.server.LBS;
import com.lutris.appserver.server.session.*;
import com.lutris.appserver.server.user.*;
import com.lutris.appserver.server.*;
import com.lutris.appserver.server.httpPresentation.*;

import demoApp.business.user.*;

/**
 * Application class for this specific application.  This implements
 * standard startup and shutdown methods and well as application specific
 * ones.
 */
public class DemoApp extends StandardApplication {
    /**
     * User manager for this application.
     */
    private DemoAppUserManager userManager = null;

    /**
     * An application random number generator used in examples.
     */
    public Random randomNumberGenerator = new Random();

    /**
     * Return the UserManager for this server.
     */
    public DemoAppUserManager getUserManager() {
        return userManager;
    }
    
    /**
     * Start the application.
     * 
     * @param appConfig Configuration file name that was specified in the
     * servlet properties file.
     * @exception ApplicationException If an error occurs starting the
     *	application.
     */
    public void startup(Config appConfig) throws ApplicationException {
        super.startup(appConfig);
        if (logChannel != null)
            logChannel.write(Logger.INFO, 
                             "Welcome to the Lutris DemoApp application!");
        try {
            userManager = new DemoAppUserManager();
        } catch (Exception e) {
            // N.B. If shutdown methods are available for session and user
            // manager, call them.
            userManager = null;

            // This application isn't designed to be restarted.
            state = DEAD;
            if (e instanceof ApplicationException) {
                throw (ApplicationException)e;
            } else {
                throw new ApplicationException("failure to initialize DemoApp", e);
            }
        }
        state = RUNNING;
    }

    /**
     * Shutdown the application.
     */
    public void shutdown() {
        super.shutdown();
        userManager = null;
    }

    public boolean requestPreprocessor(HttpPresentationComms comms)
        throws Exception {
        super.requestPreprocessor(comms);
 
        String pp = comms.request.getPresentationPath();
        if (!pp.endsWith("/"))
            pp += "/";
        String loginDir = pp + "login/";
        String mediaDir = pp + "media/";
        String page = comms.request.getRequestURI();

        if (page.startsWith(loginDir) || 
	    page.startsWith(mediaDir) ||
            page.endsWith(".html")) {
            /*
             * Let them go to the login and logout areas whether or not
             * they are logged in.  Also let them get media on welcome page.
             */
            return false;
        } else {
            /*
             * All other pages require the user to be logged in.
             */
            if (comms.session.getUser() != null)
                // It's ok, they are logged in already.
                return false;
            else {
                // They are not logged in! Redirect to login page.
                String url = pp + "login/Login.po";
                // System.out.println("Request = " + page);
                // System.out.println("Redirecting to " + url);
                throw new ClientPageRedirectException(url);
            }
        }
    }

}
