/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * 
 */

package demoApp.presentation.examples;

import com.lutris.appserver.server.httpPresentation.*;
import com.lutris.mime.*;
import java.io.*;

public class FormUpload implements HttpPresentation {
    
    private static final String NL = "\r\n"; // Correct newline for HTML.
    
    private static final String formName = "myForm";

    //
    // Workaround to pass the filename of the uploaded file without
    // it being mangled by string quoting bugs on certain browsers.
    // Uses JavaScript to copy the file name to a hidden form field
    // called "theFileName" when the form is submitted.
    //
    private static final String fileNameFix = NL
	+ "<script language=\"JavaScript\">" + NL
	+ "function setFileName() {" + NL
	+ "	var theForm = document." + formName + ";" + NL
	+ "	theForm.theFileName.value = theForm.upload.value;" + NL
	+ "}" + NL
	+ "</script>" + NL;

    private static final String headHTML = "<HTML>"
	+ fileNameFix
	+ "<HEAD><TITLE>JDDI HTML Example: Form Upload</TITLE></HEAD>"
	+ "<BODY BGCOLOR=white> <CENTER>"
        + "<TABLE COLS=3 WIDTH=\"100%\"><TR><TD></TD><TD ALIGN=CENTER>"
        + "<IMG SRC=\"../media/logo.gif\" ALT=\"Enhydra!\"></TD>"
        + "<TD ALIGN=RIGHT><A HREF=\"http://www.enhydra.org\""
        + "TARGET=\"Enhydra\"><IMG SRC=\"../media/LBSPower.gif\""
        + "ALT=\"Powered By Enhydra!\" BORDER=\"0\"></A></TD></TR></TABLE>"
	+ "</CENTER> <CENTER> <B><FONT FACE=\"Arial,Helvetica\" SIZE=+3>"
	+ "Enhydra Demonstration Application<BR>"
        + "Form Upload</FONT></B></CENTER><BR>"
        + "<CENTER><A HREF=\"HomePage.po\">"
        + "<IMG SRC=\"../media/home1.gif\" NAME=\"Home\" ALT=\"Home\" BORDER=0>"
        + "</A></CENTER><BR>"
        + "<CENTER> <TABLE COLS=1 WIDTH=\"60%\"><TR><TD>"
        + "<FONT FACE=\"Arial,Helvetica\" SIZE=+1>"
        + "This page demonstrates form field uploads to the server including "
        + "the special case where the form field is a file to upload.<P>"
        + "</FONT>"
        + "<FONT FACE=\"Arial,Helvetica\">"
        + "Please enter any text into <B>Input1</B>, select a file from your "
        + "system for <B>Upload</B>, and hit the <B>Submit</B> button.  "
        + "You will then see the results of this form upload, including the "
        + "Bytes read for each field, and the name and location of the "
        + "corresponding output files on your server.<P>"
        + "</FONT></TD></TR></TABLE></CENTER></BODY>";
    private static final String formHTML = "<P><P>" + NL
	+ "<FORM name=\"" 
	+ formName + "\" enctype=\"multipart/form-data\" "
	+ "method=POST action=FormUpload.po>" + NL
	+ NL
	+ "<INPUT type=hidden name=theFileName>" + NL
	+ NL
	+ "<H2>Input1: </H2><INPUT type=text name=input1 size=30>" + NL
	+ NL
	+ "<H2>Upload: </H2><INPUT type=file name=upload size=30>" + NL
	+ NL + "<P>"
	+ "<H2>Submit: </H2><INPUT type=submit name=submit size=30 onClick=\"setFileName()\">" + NL
	+ NL
	+ "</FORM>" + NL + NL;
    private static final String resultHTML = ""
	+ "<H1><CENTER>Upload Results</CENTER></H1>" + NL + NL;

    public void run(HttpPresentationComms comms)
        throws Exception
    {
	// For this example,
        // we don't care if you are logged in or not, so we don't
	// do any authentication.

        comms.response.setContentType("text/html");
        comms.response.setStatus(HttpPresentationResponse.SC_OK, "Good job");

        HttpPresentationOutputStream output = comms.response.getOutputStream();
	String contentType = comms.request.getContentType();

	output.print(headHTML);
        output.flush();

	if (contentType == null)
            contentType = "";

	ContentHeader contentHdr =
	    new ContentHeader("Content-Type: " + contentType);
	
	if (!contentHdr.getValue().toLowerCase().startsWith("multipart/")) {
	    // We're processing the form upload itself.
	    output.print(formHTML);
	    output.flush();
	    return;
	}

	output.print(resultHTML);

	HttpPresentationInputStream input = comms.request.getInputStream();

	MultipartMimeInput mime = new MultipartMimeInput(input, contentHdr);

	MultipartMimeInputStream in;

	while ((in = mime.nextPart()) != null) {

	    String type;
	    
	    MimeHeader hdr = in.getHeader("Content-Type");
	    if (hdr != null) {
		ContentHeader chdr = new ContentHeader(hdr);
		type = chdr.getValue();
	    } else {
		type = "null";
	    }
	    
	    String contentDisp = null;
	    String contentName = null;
	    String fileName = null;
	    if ((hdr = in.getHeader("Content-Disposition")) != null) {
		ContentHeader chdr = new ContentHeader(hdr);
		contentDisp = chdr.getValue();
		contentName = chdr.getParameter("name");
		fileName = chdr.getParameter("filename");
	    }
	    if (contentDisp == null) contentDisp = "null";
	    if (contentName == null) contentName = "null";
	    if (fileName == null) fileName = "null";
	    
	    int n, count=0;
	    byte[] buffer = new byte[1024];

	    if (contentName.equals("theFileName")) {
		StringBuffer sb = new StringBuffer();
		while ((n = in.read(buffer, 0, buffer.length)) > 0) {
		    for (int i=0; i<n; i++) {
			sb.append((char)(((int)(buffer[i])+0x100)&0xff));
		    }
		}
		String fixedFileName = new String(sb);
		String html = NL
		    + "<CENTER><H3>JavaScript File Name Workaround"
		    +	"</H3></CENTER>" + NL + "<P>" + NL
		    + "File Name: " + fixedFileName + NL + "<P>" + NL
		    + "<HR>" + NL;
		output.print(html);
	    } else {
		String outFileName = "/tmp/" +
		    contentName + System.currentTimeMillis();

		FileOutputStream out = new FileOutputStream(outFileName); 


		while ((n = in.read(buffer, 0, buffer.length)) > 0) {
		    out.write(buffer, 0, n);
		    count += n;
		}

		in.close();	  // Close this part (but not whole upload).
		out.close();  // Close output file.

		String html = NL
		    + "<CENTER><H3>Form field: " + contentName
		    +	"</H3></CENTER>" + NL + "<P>" + NL
		    + "Form field name: " + contentName + NL + "<P>" + NL
		    + "Content Type: " + type + NL + "<P>" + NL
		    + "Content Disposition: " + contentDisp + NL + "<P>" + NL
		    + "Bytes read: " + count + NL + "<P>" + NL
		    + "Output file: " + outFileName + NL + "<P>" + NL
		    + "<HR>" + NL;
		output.print(html);
	    }
	}

        // Display the form.
        output.print(formHTML);
        output.flush();
    }

}
