/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-1999 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * /root/test/poker/data/DODS_GameData/GameDataDO.java
 *-----------------------------------------------------------------------------
 */

package poker.data.DODS_GameData;

import com.lutris.appserver.server.sql.*;
import com.lutris.appserver.server.LBS;
import com.lutris.util.Config;
import com.lutris.util.KeywordValueTable;
import com.lutris.dods.builder.sourceGenerators.Query.NonUniqueQueryException;
import com.lutris.dods.builder.sourceGenerators.Query.DataObjectException;
import java.sql.*;
import java.math.*;
import java.util.Hashtable;
import java.util.Enumeration;


/**
 * Data core class, used to set, retrieve the GameDataDO information.
 *
 * @version $Revision: 1.2 $
 * @author  root
 * @since   poker
 */
 public class GameDataDO extends com.lutris.dods.builder.sourceGenerators.DO.GenericDO {

    /**
     * The ObjectId is the unique key for the DO in the database.
     */

    /**
     * A DO class contains a reference to a DataStruct class.
     * This reference can be null (when the data for the DO 
     * has not yet been retrieved from the database),
     * allowing a DO object to be a lightweight placeholder
     * until its data is needed.
     */
    private GameDataDataStruct data = null;

    /**
     * Protected constructor.  Only derived classes should call it.
     *
     * @exception com.lutris.appserver.server.sql.ObjectIdException
     *   If an object id can't be allocated for this object.
     */
    protected GameDataDO ()
    throws ObjectIdException, DatabaseManagerException {
        super();
    }

    /**
     * loadData() 
     * Load the fields for the DO from the database.
     *
     * @exception DataObjectException
     *   If an object id can't be allocated for this object.
     * @exception SQLException
     *   If an object id can't be allocated for this object.
     */
    public void loadData() 
    throws SQLException, ObjectIdException, DataObjectException 
    {
	if ( null == data ) {
	    
	    data = new GameDataDataStruct ();
	}

	

	ObjectId id = getOId();
	if ( null == id )
	    return;

	// an id means we complain if no record in database
	GameDataQuery query = new GameDataQuery ();
	query.setQueryOId( id );
	query.requireUniqueInstance();
	GameDataDO obj;
	try {
	    while ( null != ( obj = query.getNextDO() ) ) {
	        data = obj.data;
	        // obj.data.readOnly = true;
	        cache.put( obj.getOId().toString(), obj );
	    }
	} catch ( NonUniqueQueryException e ) { 
	    throw new ObjectIdException( "Duplicate ObjectId" );
	}

	
    }

    

    /**
     * A DO class that contains unchanging (static) data from the database
     * will have a cache of DOs representing the entire contents of the table.
     */
    static { 
        if ( false ) {
    	       try {
    		    
    		    refreshCache();
    		    
    	       } catch ( Exception e ) { 
    		    // cannot throw from static block
    	       }
    	   }
    }

    /**
     * The cache is used automatically by the class.
     * Callers of the create() methods do not know whether
     * the returned DO instance is shared or not.
     * This prevents the existence of multiple instances in memory 
     * of the same database object.
     * The cache is instantiated when the first DO instance is created.
     * After the cache is instantiated, the Query class for this DO
     * will search only the cache.
     */
    
    private static Hashtable cache = null;
    

    /**
     * Queries all rows in table, and for each row
     * creates a DO instance in the cache.  
     * For these DOs, data.readOnly = true,
     * which causes set methods to throw an exception.
     *
     * @exception java.sql.SQLException
     *   If an unrecoverable error occurs.
     */
    
    public static void refreshCache()
    throws java.sql.SQLException, DatabaseManagerException, ObjectIdException,
	   DataObjectException {
	    cache = new Hashtable();
	    GameDataQuery query = new GameDataQuery ();
	    GameDataDO obj;
	    try {
		while ( null != ( obj = query.getNextDO() ) ) {
		    obj.data.readOnly = true;
		    cache.put( obj.getOId().toString(), obj );
		}
	    } catch ( NonUniqueQueryException e ) { 
		// Since we do not call query.requireUniqueInstance()
		// this should never happen.
		throw new ObjectIdException( "Duplicate ObjectId" );
	    }
    }
    

    /**
     * Retrieve contents of cache as an enumeration of DO objects.
     */
    public static Enumeration getCacheContents() {
	Enumeration ret = null;
	Hashtable h = null;
	
	h = cache;
	
	if ( null != h ) 
	    ret = h.elements();
        return ret;
    }

    /**
     * createVirgin() 
     * Creates a DO that has no ObjectId or data.
     * Such a DO is used to insert a new database entry
     * after its data has been set.
     */
    
    public static GameDataDO createVirgin()
    throws DatabaseManagerException, ObjectIdException {
	return new GameDataDO ();
    }
    

    /**
     * createExisting() 
     * Creates a DO that represents an existing entry in the database.
     * Such a DO is used to examine and possibly update such an entry.
     * createExisting() is called only from the code that retrieves
     * an ObjectId from a ResultSet (database query result).
     * createExisting() is protected because no other DO or BO should ever
     * need to call it.
     * FIX unfortunately the createExisting(BigDecimal) form *does* need 
     * to be public because it is called by the public ctors of other DOs.
     * For example,
     *    AaaDO contains a ref to a BbbDO,
     *    so there is a method AaaDO.setBbb(BbbDO).
     *    In the ctor AaaDO(ResultSet), we have the call
     *       setBbb( BbbDO.createExisting( rs.getBigDecimal( "bbb", 0 )));
     * Since AaaDO is not in the same package as BbbDO,
     * BbbDO.createExisting(BigDecimal) must be public, not protected.
     * Java needs the C++ 'friend' idea.
     */
    
    public static GameDataDO createExisting( BigDecimal bd ) 
    throws SQLException, ObjectIdException, DataObjectException, DatabaseManagerException
    {
	return createExisting( new ObjectId( bd ) );
    }
    protected static GameDataDO createExisting( ObjectId id ) 
    throws SQLException, ObjectIdException, DataObjectException, DatabaseManagerException
    {
	GameDataDO ret = new GameDataDO ();
	  ret.setOId( id );
	if ( ! false )
	    ret.loadData();
	return ret;
    }

    protected static GameDataDO createExisting( ResultSet rs )
    throws SQLException, ObjectIdException, DataObjectException
		, DatabaseManagerException
    {
	GameDataDO ret = new GameDataDO ( rs );
	return ret;
    }
    

    /**
     * createCopy() 
     * Creates a DO that has no ObjectId
     * but has a copy of an existing DO's data.
     * Such a DO is used to insert a new database entry
     * that is largely similar to an existing entry.
     */
    
    public static GameDataDO createCopy( GameDataDataStruct data )
    throws DatabaseManagerException, ObjectIdException {
	GameDataDO ret = new GameDataDO ();
	ret.data = ( GameDataDataStruct ) data.duplicate();
	return ret;
    }
    

    /**
     * createCopy() 
     * Creates a DO that has no ObjectId
     * but has a copy of an existing DO's data.
     * Such a DO is used to insert a new database entry
     * that is largely similar to an existing entry.
     */
    
    public static GameDataDO createCopy( GameDataDO orig )
    throws DatabaseManagerException, ObjectIdException {
	GameDataDO ret = new GameDataDO ();
	if ( null != orig.data ) {
	    ret.data = ( GameDataDataStruct ) orig.data.duplicate();
	}
	return ret;
    }
    

    /**
     * reload() 
     * Causes the DO to refresh itself from the database
     * the next time a set or get method is called.
     */
    
    public void reload() {
	data = null;
    }
    

    /** 
     * The methods <CODE>
     *     getHandle
     *     hasMatchingHandle
     *     findCachedObjectByHandle
     * </CODE> are used by Presentation Objects that need to populate
     * HTML select lists with Data Objects as options.
     * The <CODE>getHandle()</CODE> method is used
     * to set the value for each option,
     * and the <CODE>hasMatchingHandle()<CODE>
     * and <CODE>findCachedObjectByHandle()<CODE>
     * methods are used to lookup the Data Object when the selection has
     * been made.
     *
     * @return id of this DO as a string
     *   If an object id can't be allocated for this object.
     */
    
    public        String  getHandle() 
    throws DatabaseManagerException {
	String ret = null;
	    if ( null == getOId() )
		   throw new DatabaseManagerException( "ID not set" );
	    ret = getOId().toString();
        return ret;
    }
    

   /**
     * hasMatchingHandle
     *
     * @param handle
     *   <CODE>String</CODE> version of DO id
     * @return boolean
     *   True if the string version of the id of this DO matches passed handle
     * @see getHandle
     */
    
    public        boolean hasMatchingHandle( String handle ) {
	boolean ret = false;
	    if ( null == getOId() )
		   ret = false;
	    else
		   ret = getOId().toString().equals( handle );
        return ret;
    }
    

   /**
     * findCachedObjectByHandle
     *
     * @param handle
     *   <CODE>String</CODE> version of DO id
     * @return <CODE>GameDataDO</CODE>
     *   Object if one is found in cache, otherwise null.
     * @see getHandle
     */
    
    public static GameDataDO findCachedObjectByHandle( String handle ){
        if ( null == handle ) 
            return null;
        if ( null == cache ) 
            return null;
        return ( GameDataDO ) cache.get( handle );
    }
    

    


   /**
    * Get Cash of the GameData
    *
    * @return Cash of the GameData
    */
   public int getCash () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.Cash;
   }

   /**
    * Set Cash of the GameData
    *
    * @param Cash of the GameData
    */
   
   public void setCash ( int Cash )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.Cash =  markNewValue(
	data.Cash, Cash  );
   }
   

   /**
    * Get Deck of the GameData
    *
    * @return Deck of the GameData
    */
   public String getDeck () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.Deck;
   }

   /**
    * Set Deck of the GameData
    *
    * @param Deck of the GameData
    */
   
   public void setDeck ( String Deck )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.Deck =  markNewValue(
	data.Deck, Deck , 0, 32, true );
   }
   

   /**
    * Get Email of the GameData
    *
    * @return Email of the GameData
    */
   public String getEmail () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.Email;
   }

   /**
    * Set Email of the GameData
    *
    * @param Email of the GameData
    */
   
   public void setEmail ( String Email )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.Email =  markNewValue(
	data.Email, Email , 0, 32, true );
   }
   

   /**
    * Get LargestBet of the GameData
    *
    * @return LargestBet of the GameData
    */
   public int getLargestBet () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.LargestBet;
   }

   /**
    * Set LargestBet of the GameData
    *
    * @param LargestBet of the GameData
    */
   
   public void setLargestBet ( int LargestBet )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.LargestBet =  markNewValue(
	data.LargestBet, LargestBet  );
   }
   

   /**
    * Get Name of the GameData
    *
    * @return Name of the GameData
    */
   public String getName () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.Name;
   }

   /**
    * Set Name of the GameData
    *
    * @param Name of the GameData
    */
   
   public void setName ( String Name )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.Name =  markNewValue(
	data.Name, Name , 0, 32, false );
   }
   

   /**
    * Get Password of the GameData
    *
    * @return Password of the GameData
    */
   public String getPassword () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.Password;
   }

   /**
    * Set Password of the GameData
    *
    * @param Password of the GameData
    */
   
   public void setPassword ( String Password )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.Password =  markNewValue(
	data.Password, Password , 0, 32, true );
   }
   

   /**
    * Get SmallestBet of the GameData
    *
    * @return SmallestBet of the GameData
    */
   public int getSmallestBet () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.SmallestBet;
   }

   /**
    * Set SmallestBet of the GameData
    *
    * @param SmallestBet of the GameData
    */
   
   public void setSmallestBet ( int SmallestBet )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.SmallestBet =  markNewValue(
	data.SmallestBet, SmallestBet  );
   }
   

   /**
    * Get TotalPlayed of the GameData
    *
    * @return TotalPlayed of the GameData
    */
   public int getTotalPlayed () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.TotalPlayed;
   }

   /**
    * Set TotalPlayed of the GameData
    *
    * @param TotalPlayed of the GameData
    */
   
   public void setTotalPlayed ( int TotalPlayed )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.TotalPlayed =  markNewValue(
	data.TotalPlayed, TotalPlayed  );
   }
   

   /**
    * Get TotalWon of the GameData
    *
    * @return TotalWon of the GameData
    */
   public int getTotalWon () 
   throws DataObjectException {
      if ( null == data )
 	try {
 	  loadData();
 	} catch ( Exception e ) {
 	  throw new DataObjectException( 
 	    "Unable to load data for GameDataDO id=" + getOId() +
 	    ", error = " + e.getMessage() );
        }
      return data.TotalWon;
   }

   /**
    * Set TotalWon of the GameData
    *
    * @param TotalWon of the GameData
    */
   
   public void setTotalWon ( int TotalWon )
   throws DataObjectException {
      if ( null == data )
	try {
	  loadData();
	} catch ( Exception e ) {
	  throw new DataObjectException( 
	    "Unable to load data for GameDataDO id=" + getOId() +
	    ", error = " + e.getMessage() );
	}
      data.TotalWon =  markNewValue(
	data.TotalWon, TotalWon  );
   }
   
    /**
     * Protected constructor.
     *
     * @param rs
     *   Result set from which to obtain product data.
     * @exception java.sql.SQLException
     *   If a database connection error occurs.
     * @exception com.lutris.appserver.server.sql.ObjectIdException
     *   If the database contains an invalid object id.
     */
    protected GameDataDO(ResultSet rs)
            throws SQLException, ObjectIdException, DataObjectException
 	    , DatabaseManagerException
/*  	      */
    {
        super(rs);

	// Constructing a DO from a ResultSet means we definitely need the 
	// DataStruct ready for the setXxx methods invoked below.
	data = new GameDataDataStruct ();
 
	// writeMemberStuff uses the ResultSetExtraction.template
	// to build up the value for this tag:
	// the value is a series of calls to the DO set methods.
		
	setCash( 
	    
		rs.getInt( 
			"Cash"  )
	    
	);
	
	
	setDeck( 
	    
		rs.getString( 
			"Deck"  )
	    
	);
	
	
	setEmail( 
	    
		rs.getString( 
			"Email"  )
	    
	);
	
	
	setLargestBet( 
	    
		rs.getInt( 
			"LargestBet"  )
	    
	);
	
	
	setName( 
	    
		rs.getString( 
			"Name"  )
	    
	);
	
	
	setPassword( 
	    
		rs.getString( 
			"Password"  )
	    
	);
	
	
	setSmallestBet( 
	    
		rs.getInt( 
			"SmallestBet"  )
	    
	);
	
	
	setTotalPlayed( 
	    
		rs.getInt( 
			"TotalPlayed"  )
	    
	);
	
	
	setTotalWon( 
	    
		rs.getInt( 
			"TotalWon"  )
	    
	);
	

 
        markClean();
    }

    

    

    private int[] param = null;

    /**
     * Prepares the statement used to insert this object
     * into the database.
     * @param conn the database connection.
     * @return the insert statement.
     * @exception java.sql.SQLException if an error occurs.
     */
    public PreparedStatement getInsertStatement(DBConnection conn)
            throws SQLException {

        ObjectId oid;

        PreparedStatement stmt = conn.prepareStatement( 
	    "insert into GameData values ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )" );

	param = new int[1]; param[0] = 1;
	// writeMemberStuff uses the JDBCsetCalls.template
	// to build up the value for this tag:
	// the value is a series of calls to setPrepStmtParam_TYPE methods.
	// Those methods are defined below.
	try {
	    	setPrepStmtParam_int( stmt, param,
		getCash() );
	setPrepStmtParam_String( stmt, param,
		getDeck() );
	setPrepStmtParam_String( stmt, param,
		getEmail() );
	setPrepStmtParam_int( stmt, param,
		getLargestBet() );
	setPrepStmtParam_String( stmt, param,
		getName() );
	setPrepStmtParam_String( stmt, param,
		getPassword() );
	setPrepStmtParam_int( stmt, param,
		getSmallestBet() );
	setPrepStmtParam_int( stmt, param,
		getTotalPlayed() );
	setPrepStmtParam_int( stmt, param,
		getTotalWon() );


	    /* The order of the values being inserted must match
	     * the order of the columns listed in the CREATE TABLE command
	     * that appears in the .sql file for this DO.
	     * Since the id and version number are always the last columns
	     * listed in the CREATE TABLE command, their values are added
	     * to the PreparedStatement after all other values.
	     */
	    setPrepStmtParam_BigDecimal( stmt, param, getOId().toBigDecimal() );
	    setPrepStmtParam_int(        stmt, param, getNewVersion() );

	} catch ( Exception e ) {
	    throw new SQLException( "Data Object error: " + e.getMessage() );
	}

        return stmt;
    }

    /**
     * Prepares the statement used to update this object
     * in the database.
     * @param conn the database connection
     * @return the update statement.
     * @exception java.sql.SQLException if an error occurs.
     */
    public PreparedStatement getUpdateStatement(DBConnection conn)
            throws SQLException {

        ObjectId oid;

        PreparedStatement stmt = conn.prepareStatement(
	    "update GameData set Cash = ?, Deck = ?, Email = ?, LargestBet = ?, Name = ?, Password = ?, SmallestBet = ?, TotalPlayed = ?, TotalWon = ? " +
	    "where oId = ? and version = ?" );

	param = new int[1]; param[0] = 1;
	//int[] param = {1};
	// writeMemberStuff builds up the value for this tag:
	// the value is a series of calls to setPrepStmtParam_TYPE methods.
	// Those methods are defined below.
	try {
	    	setPrepStmtParam_int( stmt, param,
		getCash() );
	setPrepStmtParam_String( stmt, param,
		getDeck() );
	setPrepStmtParam_String( stmt, param,
		getEmail() );
	setPrepStmtParam_int( stmt, param,
		getLargestBet() );
	setPrepStmtParam_String( stmt, param,
		getName() );
	setPrepStmtParam_String( stmt, param,
		getPassword() );
	setPrepStmtParam_int( stmt, param,
		getSmallestBet() );
	setPrepStmtParam_int( stmt, param,
		getTotalPlayed() );
	setPrepStmtParam_int( stmt, param,
		getTotalWon() );


	    /* When updating a persistent object, the UPDATE_WHERE_CLAUSE tag
	     * used to build the SQL WHERE clause (above) uses the 
	     * DO's id and version number to locate the correct row in
	     * the database table.
	     */
	    setPrepStmtParam_BigDecimal( stmt, param, getOId().toBigDecimal() );
	    setPrepStmtParam_int(        stmt, param, getVersion() );

	} catch ( Exception e ) {
	    throw new SQLException( "Data Object error: " + e.getMessage() );
	}

        return stmt;
    }

    /**
     * Prepares the statement used to delete this object
     * from the database.
     * @param conn the database connection
     * @return the delete statement.
     * @exception java.sql.SQLException if an error occurs.
     */
    public PreparedStatement getDeleteStatement(DBConnection conn)
            throws SQLException {
        String sql =
            "delete from GameData \n" +
            "where oId = ?";
        PreparedStatement stmt = conn.prepareStatement(sql);
        stmt.setBigDecimal(1, getOId().toBigDecimal());
        return stmt;
    }

    

    /*
     * toString - for debugging
     */
    public String toString(){
        return "GameDataDO dump: " + " Cash=" + data.Cash
+ " Deck=" + data.Deck
+ " Email=" + data.Email
+ " LargestBet=" + data.LargestBet
+ " Name=" + data.Name
+ " Password=" + data.Password
+ " SmallestBet=" + data.SmallestBet
+ " TotalPlayed=" + data.TotalPlayed
+ " TotalWon=" + data.TotalWon
 + ".";
    }

}
